@@ -12,4 +12,11 @@ class TestWebhook < Test::Unit::TestCase
     @webhook.notify('msg', Time.now, 'prio', 'cat', 'host')
     assert_equal "sent webhook to http://example.com/switch", @webhook.info
   end
+
+  def test_notify_with_url_containing_query_parameters
+    @webhook.url = 'http://example.com/switch?api_key=123'
+    Net::HTTP::Post.expects(:new).with('/switch?api_key=123')
+
+    @webhook.notify('msg', Time.now, 'prio', 'cat', 'host')
+  end
 end
